@@ -149,7 +149,8 @@ void ThemeEditorMainWindow::slotInstallTheme()
 {
     // Save before installing :)
     if (slotSaveTheme()) {
-        const QString localThemePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kaddressbook/printing/themes");
+        const QString localThemePath =
+            QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1StringView("/kaddressbook/printing/themes");
         if (QDir().mkpath(localThemePath)) {
             mThemeEditor->installTheme(localThemePath);
         }
@@ -199,7 +200,7 @@ void ThemeEditorMainWindow::slotOpenTheme()
 bool ThemeEditorMainWindow::loadTheme(const QString &directory)
 {
     if (!directory.isEmpty()) {
-        const QString filename = directory + QLatin1String("/theme.themerc");
+        const QString filename = directory + QLatin1StringView("/theme.themerc");
         if (!QFileInfo::exists(filename)) {
             KMessageBox::error(this, i18n("Directory does not contain a theme file. We cannot load theme."));
             return false;
